@@ -3,6 +3,7 @@ import argparse
 import itertools
 import json
 import logging
+import shutil
 from multiprocessing.pool import ThreadPool
 from pathlib import Path
 
@@ -10,14 +11,19 @@ from . import __version__
 from .core import auth, download_tweet, get_bookmarks
 
 
-class CapitalisedHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
+class CapitalizedHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
     """Use a more sane capitaliztion in help argparse help menus."""
 
+    def __init__(self, prog: str) -> None:
+        """Use the terminal width to determine width."""
+        width, height = shutil.get_terminal_size((80, None))
+        super().__init__(prog, width=width)
+
     def add_usage(self, usage, actions, groups, prefix=None):
         """Usage formatter."""
         if prefix is None:
             prefix = "Usage: "
-        return super(CapitalisedHelpFormatter, self).add_usage(
+        return super(CapitalizedHelpFormatter, self).add_usage(
             usage,
             actions,
             groups,
@@ -42,7 +48,7 @@ def build_parser(exit_on_error: bool = True) -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(
         add_help=False,
         description="A CLI Tool to archive tweets",
-        formatter_class=CapitalisedHelpFormatter,
+        formatter_class=CapitalizedHelpFormatter,
         exit_on_error=exit_on_error,
     )
 
@@ -51,14 +57,18 @@ def build_parser(exit_on_error: bool = True) -> argparse.ArgumentParser:
     parser._optionals.title = "Options"
 
     parser.add_argument(
-        "-o",
-        "--media-output",
-        metavar="FILE",
+        "--client-id",
         action="store",
-        type=Path,
-        default=Path("./media"),
-        help="Path to output downloaded media.",
+        metavar="ID",
+        help="Specify the client ID.",
     )
+    parser.add_argument(
+        "--client-secret",
+        action="store",
+        metavar="ID",
+        help="Specify the client ID.",
+    )
+
     parser.add_argument(
         "--headless",
         action="store_true",
@@ -69,11 +79,6 @@ def build_parser(exit_on_error: bool = True) -> argparse.ArgumentParser:
         action="store_true",
         help="Don't redownload/overwrite existing media.",
     )
-    parser.add_argument(
-        "--quiet",
-        action="store_true",
-        help="Disable download progress bars",
-    )
     parser.add_argument(
         "--num-download-threads",
         metavar="N",
@@ -82,25 +87,30 @@ def build_parser(exit_on_error: bool = True) -> argparse.ArgumentParser:
         help="Number of threads to use while downloading media.",
     )
     parser.add_argument(
-        "-v",
-        "--verbose",
-        action="count",
-        default=0,
+        "--quiet",
+        action="store_true",
+        help="Disable download progress bars",
     )
     parser.add_argument(
-        "-h",
-        "--help",
-        action="help",
-        default=argparse.SUPPRESS,
-        help="Show this help message ane exit.",
-    )
-    parser.add_argument(
-        "--version",
-        action="version",
-        version=f"%(prog)s {__version__}",
+        "-o",
+        "--media-output",
+        metavar="FILE",
+        action="store",
+        type=Path,
+        default=Path("./media"),
+        help="Path to output downloaded media.",
     )
 
+    # Mutually exclusive options.
     manifest_group = parser.add_mutually_exclusive_group()
+    manifest_group.add_argument(
+        "-i",
+        "--manifest-input",
+        action="store",
+        metavar="FILE",
+        type=Path,
+        help="Use an existing manifest and download all media.",
+    )
     manifest_group.add_argument(
         "-m",
         "--manifest-output",
@@ -110,13 +120,24 @@ def build_parser(exit_on_error: bool = True) -> argparse.ArgumentParser:
         default=Path("./bookmark-manifest.json"),
         help="Path to output bookmark manifest.",
     )
-    manifest_group.add_argument(
-        "-i",
-        "--manifest-input",
-        action="store",
-        metavar="FILE",
-        type=Path,
-        help="Use an existing manifest and download all media.",
+
+    # Generic
+    parser.add_argument(
+        "-v",
+        "--verbose",
+        action="count",
+        default=0,
+    )
+    parser.add_argument(
+        "--version",
+        action="version",
+        version=f"%(prog)s {__version__}",
+    )
+    parser.add_argument(
+        "--help",
+        action="help",
+        default=argparse.SUPPRESS,
+        help="Show this help message ane exit.",
     )
 
     return parser
@@ -161,7 +182,12 @@ def main() -> None:
     logger = _setup_logging(args["verbose"])
 
     logger.debug("Authenticating")
-    client = auth(headless=args["headless"], use_dotenv=True)
+    client = auth(
+        headless=args["headless"],
+        client_id=args["client_id"],
+        client_secret=args["client_secret"],
+        use_dotenv=True,
+    )
 
     if args["manifest_input"] is not None:
         logger.info("Loaded existing manifest from '%s'", args["manifest_input"])
